@@ -4,7 +4,8 @@ import json
 from decouple import config
 import requests
 
-
+def main():
+    return "DDD"
 class logs_hub:
 
 
